include TeX.mk

#NAME	  ?=
# Directory of the web page
# Subdirectory for preprints
WWW = $(HOME)/www
PREPRINTS = $(HOME)/www/Preprints/

# FIG_DIR
# FIG_FILES
# GML_FILES
# FIGTEX_FILES
FIG_BASE?=Fig
FIG_DIR=$(wildcard $(FIG_BASE)/ */$(FIG_BASE)/ $(FIG_BASE)/graphes/ $(FIG_BASE)/stats/ $(FIG_BASE)/autogen/)
FIG_FILES:=$(wildcard $(FIG_DIR:%=%*.fig))
GML_FILES:=$(wildcard $(FIG_DIR:%=%*.gml))
FIGTEX_FILES:= $(FIG_FILES:%.fig=%.eps) $(GML_FILES:%.gml=%.eps)
FIGURES=$(patsubst %,%.eps,$(shell cat FIGURES 2>/dev/null))
FIG_FILES:=$(wildcard $(FIG_DIR:%=%*.fig))
FIGPDF_FILES:= $(patsubst %.ps,%.pdf, $(wildcard $(FIG_DIR:%=%*.ps)))\
       $(patsubst %.eps,%.pdf, $(wildcard $(FIG_DIR:%=%*.eps)))
#FIG2DEVFLAGS+=-m .5

TEX_FILES+=$(wildcard *.tex) $(wildcard */*.tex)

##############################################################################
# dpendances...

.phony: bib fig index timeall  _FORCE_

_FORCE_:

timeall:
	time make all > compilation.log 2>&1

main.dvi: fig
	@echo 'tape 1: simple compilation + bibtex'
	$(LATEX) main
	$(MAKE) bib
	@echo 'tape 2: simple compilation'
	$(LATEX) main
	@echo 'tape 3: compilation + makeindex'
	$(LATEX) main
	-$(MAKE) index
	@echo 'tape 4: compilation finale'
	$(LATEX) main

main.pdf: main.dvi fig figpdf

clean: tex-clean hevea-clean

figpdf: $(FIGPDF_FILES)


install: $(NAME).tar.gz
	test -d $(PREPRINTS)$(NAME) || mkdir $(PREPRINTS)$(NAME)
	$(BIBTOOL) $(HOME)/TeX/bib/isil.bib -X '^$(NAME)$$' -o $(PREPRINTS)$(NAME)/$(NAME).bib -- pass.comments=on
	cp -a main.dvi  $(PREPRINTS)$(NAME)/$(NAME).dvi
	cp -a main.ps   $(PREPRINTS)$(NAME)/$(NAME).ps
	cp -a main.pdf  $(PREPRINTS)$(NAME)/$(NAME).pdf
	cp -a main.tex  $(PREPRINTS)$(NAME)/$(NAME).tex
	-cp -a main.tex.mac  $(PREPRINTS)$(NAME)/$(NAME).tex.mac
	-cp -a main.txt  $(PREPRINTS)$(NAME)/$(NAME).txt
	-cp -a main.html $(PREPRINTS)$(NAME)/$(NAME).html
	-cp -a main*.gif $(PREPRINTS)$(NAME)/
	if [ -n "$(FIGURES)" ]; then\
	    cp -Pra $(FIGURES) $(PREPRINTS)$(NAME)/;\
	fi
	cp $(NAME).tar.gz $(PREPRINTS)$(NAME)/
	cd $(WWW); make install

install-small: main.pdf
	test -d $(PREPRINTS)$(NAME) || mkdir $(PREPRINTS)$(NAME)
	cp -a main.pdf $(PREPRINTS)/$(NAME)/$(NAME).pdf
	cd $(WWW); make install

bib:	main.bbl main.bib

main.bib:
	if test -f main.bib; then rm main.bib; fi
	touch main.bib
	$(BIBTOOL) -x main.aux $(HOME)/TeX/bib/*.bib -o main.bib  -- pass.comments=on

main.bbl:
	$(BIBTEX) main

index:  main.ind

%.ind:	%.idx main.xdy
	xindy -f tex2xindy main.xdy $*.idx

fig: $(FIGTEX_FILES) $(FIGURES)

#fig: $(FIGTEX_FILES) FIGURES $(FIGURES)

figstat:
	cd Fig/stats; make

##############################################################################
# dpendances utilitaires

.phony: figlist tags2 cvs-check-add

# Pour ne pas mettre les fichiers .bib dans les TAGS.

tags2:
	etags $(TEX_FILES)

tardist: $(NAME).tar.gz

$(NAME).tar.gz: main.bib main.tex 
	-rm -rf /tmp/$(NAME)
	mkdir /tmp/$(NAME)
	if [ -n "$(FIGURES)" ]; then\
	    cp -Pra $(FIGURES) /tmp/$(NAME)/;\
	fi
	cp main.tex main.bib $(EXTRATARDIST) /tmp/$(NAME)
#	perl -pi.bak -e 's/^.bibliography{.*$$/\\bibliography{main}/;' /tmp/$(NAME)/main.tex
	cd /tmp; tar zcvf $(NAME).tar.gz $(NAME)
	mv /tmp/$(NAME).tar.gz .
	rm -rf /tmp/$(NAME)
