##############################################################################
# Useful makefile rules for TeX, LaTeX, HeVeA, xfig, ...
##############################################################################
# Provided dependencies:
# tex-clean
# tex-tags
# figtex-clean

.PHONY:	tex-clean tex-tags figtex-clean

# programmes

LATEX	 ?= latex  # 2e
PDFLATEX ?= pdflatex
BIBTEX	 ?= bibtex
BIBTOOL	 ?= bibtool
HEVEA	 ?= hevea
# HEVEAFLAGS HEVEATEXTFLAGS HEVEAHTMLFLAGS HEVEAINFOFLAGS
IMAGEN	 ?= imagen
ETAGS	 ?= etags
FIG2DEV  ?= fig2dev
# FIG2DEVFLAGS
DVIPS	 ?= dvips
DVIPSFLAGS?= -R0
EPSTOPDF ?= epstopdf
PSTOPDF  ?= ps2pdf
LYX	 ?= lyx

BIB_FILES?=

# dpendances...

##  Rgles de constructions varies

%.gz: %
	gzip $<

## Rgles de construction pour fig

%.box: %.fig
	$(FIG2DEV) -L box $(FIG2DEVFLAGS) '$<' '$@'

%.ps: %.fig
	$(FIG2DEV) -L ps $(FIG2DEVFLAGS) '$<' '$@'

%.eps: %.fig
	$(FIG2DEV) -L eps $(FIG2DEVFLAGS) '$<' '$@'

%.tex: %.fig
	$(FIG2DEV) -L latex $(FIG2DEVFLAGS) '$<' '$@'

%.epic: %.fig
	$(FIG2DEV) -L epic $(FIG2DEVFLAGS) '$<' > '$@'

%.eepic: %.fig
	$(FIG2DEV) -L eepic $(FIG2DEVFLAGS) '$<' > '$@'

%.eepicemu: %.fig
	$(FIG2DEV) -L eepicemu $(FIG2DEVFLAGS) '$<' '$@'

%.pictex: %.fig
	$(FIG2DEV) -L pictex $(FIG2DEVFLAGS) '$<' '$@'

%.textyl: %.fig
	$(FIG2DEV) -L textyl $(FIG2DEVFLAGS) '$<' '$@'

%.pstex: %.fig
	$(FIG2DEV) -L pstex $(FIG2DEVFLAGS) '$<' '$@'

%.pstex_t: %.fig
	$(FIG2DEV) -L pstex_t -p $*.pstex $(FIG2DEVFLAGS) '$<' '$@'

%.eps: %.png
	convert $< $@

##  Rgles de constructions pour tex,...

%.ps: %.dvi
	cd `dirname '$<'`; $(DVIPS) $(DVIPSFLAGS) `basename '$<'` -o

# Note: most of the latex / pdflatex / mpost / ... commands deal
# in an improper manner with files in subdirectory.
# (eg latex truc/bla.tex creates bla.dvi instead of truc/bla.dvi)
# So, we first cd to the subdirectory, and call latex there.

%.ps: %.mp
	cd `dirname '$<'`; mpost `basename '$<'`

%.eps: %.mp
	cd `dirname '$<'`; mpost `basename '$<'`

%.dvi: %.tex
	cd `dirname '$<'`; $(LATEX) `basename '$<'`

%.bbl: $(BIB_FILES) %.aux
	bibtex $*

%.aux: %.tex
	$(LATEX) $*

# utilitaires:

tex-tags:
	$(ETAGS) $(TEX_FILES) $(BIB_FILES)

tex-clean:
	-rm *.dvi *.ps 2>/dev/null
	-rm *.aux *.log *.bbl *.blg 2>/dev/null
	-rm *.lof *.toc *.lot 2>/dev/null
	-rm *.idx *.ilg *.ind

## Quelques autres conversions

%.tex: %.lyx
	if [ -f $@ ]; then mv $@ $@.bak; fi
	$(LYX) $< --export latex
	perl -pi.bak -e 's/{([\w-.]*)\.eps}/{$$1}/g' $@

%.tex.mac: %.tex
	recode latin1..mac < $< > $@

# ps / pdf

%.pdf: %.tex
	cd `dirname '$<'`; $(PDFLATEX) `basename '$<'`

%.pdf: %.eps
	$(EPSTOPDF) '$<' -o '$@'

%.pdf: %.ps
	$(PSTOPDF) '$<' '$@'

%.eps: %.gml
	gml2ps $< $@

%.eps: %.gp
	cd `dirname '$<'`; gnuplot `basename '$<'`

# hevea

%.prehtml: %.tex
	cd `dirname '$<'`; $(HEVEA) $(HEVEAFLAGS) $(HEVEAHTMLFLAGS) nodocument.hva `basename '$<'` -o `basename '$@'`
#	if test -f $*.image.tex; then $(MAKE) $(MFLAGS) $*001.gif; else test 1; fi

%.html: %.tex
	cd `dirname '$<'`; $(HEVEA) $(HEVEAFLAGS) $(HEVEAHTMLFLAGS) `basename '$<'` -o `basename '$@'`
# Uncomment if you want to be sure hevea is run twice
#	$(HEVEA) $(HEVEAFLAGS) $(HEVEAHTMLFLAGS) $< -o $@
#	if test -f $*.image.tex; then $(MAKE) $(MFLAGS) $*001.gif; else test 1; fi

%.txt: %.tex
	cd `dirname '$<'`; $(HEVEA) -text $(HEVEAFLAGS) $(HEVEATEXTFLAGS) `basename '$<'` -o `basename '$@'`

%.info: %.tex
	$(HEVEA) -info $(HEVEAFLAGS) $(HEVEAINFOFLAGS) $< -o $@

%001.gif: %.image.tex
	cd `dirname '$<'`; $(IMAGEN) `basename '$*'`

hevea-clean:
	-rm *.image.tex
	-rm *[0-9][0-9][0-9].gif
